==> vi-api-1.40.4.tgz: package/event/event-api.js <==
export const TAB_ACTIVE_EVENT = "SNG_TAB_ACTIVE";
export const CONTENT_PANE_RESIZE_EVENT = "SNG_CONTENT_PANE_RESIZE";
export var PageEvents;
(function (PageEvents) {
    PageEvents["ChildObjectOnSelect"] = "spb:ChildObjectSelect";
    PageEvents["CommentsOnShowEvent"] = "spb::Comments:onShow";
    PageEvents["DirtyStateChangeEvent"] = "spb::dirty-state-change";
    PageEvents["LoadDocumentEvent"] = "spb::page-load-all";
    PageEvents["ModeChangeEvent"] = "spb::page-mode-change";
    PageEvents["ModelChangeEvent"] = "spb::page-model-change";
    PageEvents["PanelOpenEvent"] = "spb::sliding-panel-open";
    PageEvents["RefreshAttachmentsGrid"] = "spb::refreshAttachmentsGrid";
    PageEvents["RefreshPageEvent"] = "spb::refreshPage";
    PageEvents["SelectAttachmentEvent"] = "spb::Highlighting:SelectAttachment";
    PageEvents["SelectChildObjectEvent"] = "spb::Highlighting:SelectChildObject";
    PageEvents["SelectCommentEvent"] = "spb::Highlighting:SelectComment";
    PageEvents["SelectNodeEvent"] = "spb::selectNode";
    PageEvents["UpdateSubDocumentTypeEvent"] = "spb::updateSubDocumentType";
    PageEvents["TabSelectedEvent"] = "spb::tabSelected";
    PageEvents["VisitAllTabs"] = "spb::mark-all-tabs-visited";
    PageEvents["MaskToggleEvent"] = "spb::mask-toggle";
    PageEvents["MaskAllEvent"] = "spb::mask-all";
    PageEvents["ClearDateFieldEvent"] = "spb::clear-date-field";
})(PageEvents || (PageEvents = {}));
export var DocumentGeneratorEvents;
(function (DocumentGeneratorEvents) {
    DocumentGeneratorEvents["AfterDocumentGenerated"] = "docgen::after-document-generated";
})(DocumentGeneratorEvents || (DocumentGeneratorEvents = {}));
/**
 * Callback function executed when subscription is triggered by an event.
 * @callback EventApi~subscriptionCallback
 * @param payload {any} Payload of the subscription.
 * @returns {void}
 */

==> vi-api-1.48.0.tgz: package/event/event-api.js <==
export const TAB_ACTIVE_EVENT = "SNG_TAB_ACTIVE";
export const CONTENT_PANE_RESIZE_EVENT = "SNG_CONTENT_PANE_RESIZE";
export var PageEvents;
(function (PageEvents) {
    PageEvents["ChildObjectOnSelect"] = "spb:ChildObjectSelect";
    PageEvents["CommentsOnShowEvent"] = "spb::Comments:onShow";
    PageEvents["DirtyStateChangeEvent"] = "spb::dirty-state-change";
    PageEvents["LoadDocumentEvent"] = "spb::page-load-all";
    PageEvents["ModeChangeEvent"] = "spb::page-mode-change";
    PageEvents["ModelChangeEvent"] = "spb::page-model-change";
    PageEvents["PanelOpenEvent"] = "spb::sliding-panel-open";
    PageEvents["RefreshAttachmentsGrid"] = "spb::refreshAttachmentsGrid";
    PageEvents["RefreshPageEvent"] = "spb::refreshPage";
    PageEvents["SelectAttachmentEvent"] = "spb::Highlighting:SelectAttachment";
    PageEvents["SelectChildObjectEvent"] = "spb::Highlighting:SelectChildObject";
    PageEvents["SelectCommentEvent"] = "spb::Highlighting:SelectComment";
    PageEvents["SelectNodeEvent"] = "spb::selectNode";
    PageEvents["UpdateSubDocumentTypeEvent"] = "spb::updateSubDocumentType";
    PageEvents["TabSelectedEvent"] = "spb::tabSelected";
    PageEvents["VisitAllTabs"] = "spb::mark-all-tabs-visited";
    PageEvents["MaskEvent"] = "spb::mask";
    PageEvents["UnmaskEvent"] = "spb::unmask";
    PageEvents["MaskResetEvent"] = "spb::mask-reset";
    PageEvents["ClearDateFieldEvent"] = "spb::clear-date-field";
})(PageEvents || (PageEvents = {}));
export var DocumentGeneratorEvents;
(function (DocumentGeneratorEvents) {
    DocumentGeneratorEvents["AfterDocumentGenerated"] = "docgen::after-document-generated";
})(DocumentGeneratorEvents || (DocumentGeneratorEvents = {}));
/**
 * Callback function executed when subscription is triggered by an event.
 * @callback EventApi~subscriptionCallback
 * @param payload {any} Payload of the subscription.
 * @returns {void}
 */
